Unique Delegation Manager
Unique Delegation Manager is a toolset built for managing a “master-delegate” relationship between 1-to-many wallets. Protocols that implement it can allow safe execution of numerous actions for users without exposing their assets to any risks.
Modules
- accounts
- An Anchor generated module, providing a set of structs
mirroring the structs deriving
Accounts, where each field is aPubkey. This is useful for specifying accounts for a client. - delegation_
manager - Unique program library’s Delegation Manager program.
- instruction
- An Anchor generated module containing the program’s set of
instructions, where each method handler in the
#[program]mod is associated with a struct defining the input arguments to the method. These should be used directly, when one wants to serialize Anchor instruction data, for example, when speciying instructions on a client. - program
- Module representing the program.
Structs
- Cancel
Delegation - Accounts passed to CancelDelegation instruction
- Confirm
Delegation - Accounts passed to ConfirmDelegation instruction
- Delegation
- State account storing the delegation
- Initialize
Delegation - Accounts passed to InitializeDelegation instruction
Enums
- Delegation
Error - Program errors
Constants
Statics
- ID
- The static program ID
Functions
- check_
authorization - Function used to determine if a representative is authorised by master. If the master is the same as a representative, the delegation_option argument can be None. If the master is not the same as a representative, Delegation account needs to be passed
- check_
id - Confirms that a given pubkey is equivalent to the program ID
- entry
- The Anchor codegen exposes a programming model where a user defines
a set of methods inside of a
#[program]module in a way similar to writing RPC request handlers. The macro then generates a bunch of code wrapping these user defined methods into something that can be executed on Solana. - entrypoint⚠
- Safety
- get_
delegation_ address - get_
delegation_ address_ seeds - id
- Returns the program ID